#des--test-input {
    color: white;
    background: none;
    border: 1px solid #ffffff4d;
    height: 1.15em;
    margin: -2px 0 0 0;
    border-radius: 14px;
    padding-left: 6px;
    width: 175px;
}

input#des--test-input::-webkit-input-placeholder {
    color: white;
    font-weight: lighter;
    opacity: 0.4;
}

input#des--test-input:-moz-placeholder { /* Firefox 18- */
    color: white;
    font-weight: lighter;
    opacity: 0.4;
}

input#des--test-input::-moz-placeholder {  /* Firefox 19+ */
    color: white;
    font-weight: lighter;
    opacity: 0.4;
}

input#des--test-input:-ms-input-placeholder {
    color: white;
    font-weight: lighter;
    opacity: 0.4;
}

#des--test-button.error {
    border-width: 1px;
    border-color: #ba2121;
}

#des--test-button {
    display: block;
    float: left;
    padding: 3px 4px 3px 12px;
    background: #999;
    border: 1px solid white;
    list-style-type: square;
    line-height: 20px;
    font-weight: 400;
    font-size: 11px;
    cursor: pointer;
    text-transform: uppercase;
    letter-spacing: 0.5px;
    color: #fff;
    border-radius: 15px;
    text-decoration: none;
    margin-top: -1px;
}
