# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-12-10 17:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DynamicEmailConfiguration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('host', models.CharField(blank=True, max_length=256, null=True, verbose_name='Email Host')),
                ('port', models.SmallIntegerField(blank=True, null=True, verbose_name='Email Port')),
                ('from_email', models.CharField(blank=True, max_length=256, null=True, verbose_name='Default From Email')),
                ('username', models.CharField(blank=True, max_length=256, null=True, verbose_name='Email Authentication Username')),
                ('password', models.CharField(blank=True, max_length=256, null=True, verbose_name='Email Authentication Password')),
                ('use_tls', models.BooleanField(default=False, verbose_name='Use TLS')),
                ('use_ssl', models.BooleanField(default=False, verbose_name='Use SSL')),
                ('fail_silently', models.BooleanField(default=False, verbose_name='Fail Silently')),
                ('timeout', models.SmallIntegerField(blank=True, null=True, verbose_name='Email Send Timeout (seconds)')),
            ],
            options={
                'verbose_name': 'Email Configuration',
            },
        ),
    ]
