<!--
Template courtesy of django-solo project:
https://github.com/lazybird/django-solo
-->
{% extends "admin/change_form.html" %}
{% load i18n %}
{% load admin_urls %}

{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href="{% url 'admin:index' %}">{% trans 'Home' %}</a> &rsaquo;
    <a href="../">{{ opts.app_config.verbose_name|capfirst|escape }}</a> &rsaquo;
    {{ opts.verbose_name|capfirst }}
</div>
{% endblock %}

{% block object-tools-items %}
<li><a href="{% url opts|admin_urlname:'history' %}" class="historylink">{% trans "History" %}</a></li>
<li>
    <form id="des--test-form" action="{% url 'des-test-email' %}" method="POST">
        <button type="submit" id="des--test-button">
            {% csrf_token %}
            {% trans "Send Test Email" %}:
            <input name="email" id="des--test-input" placeholder="example-email@website.com">
        </button>
    </form>
</li>
{% if has_absolute_url %}<li><a href="{% url 'admin:view_on_site' content_type_id original.pk %}" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif%}
{% endblock %}
